# Python Environment and PyMOR Setup on Windows

This repository contains two Windows CMD scripts to set up a Python environment for scientific computing, including PyMOR and its dependencies.

## Scripts Overview

### 1. `install_ode_ngsolve.bat`
**Purpose**:  
This script installs Python 3.12, essential scientific computing libraries, and the NGSolve library.

**Key Actions**:
- Checks for an existing Python installation.
- Installs Python 3.12 if not already present.
- Ensures `pip` is installed and updated.
- Installs the following Python libraries:
  - `numpy`
  - `scipy`
  - `matplotlib`
- Installs `ngsolve` for finite element analysis.

---

### 2. `install_pymor_dependencies.bat`
**Purpose**:  
This script installs C++ and Fortran compilers, the Conda package manager, and additional libraries required for PyMOR.

**Key Actions**:
- Verifies the presence of:
  - `g++` (C++ compiler)
  - `gfortran` (Fortran compiler)
  - Prompts the user to install these compilers manually if not found.
- Installs Miniconda, a lightweight Conda package manager.
- Configures Conda to prioritize the `conda-forge` channel.
- Installs the following packages via Conda:
  - `numpy`
  - `scipy`
  - `matplotlib`
  - `pymor`
  - `slycot`
- Updates all Conda packages to their latest versions.

---

## Installation Instructions

*Note:* You have to provide internet to be able to install the packages.

### Step 1: Install Python and NGSolve
1. Open a Command Prompt with administrator privileges.
2. Navigate to the directory containing the `install_ode_ngsolve.bat` script.
3. Run the script:
   ```cmd
   install_ode_ngsolve.bat

### Step 2: Install PyMOR
1. Open a Command Prompt with administrator privileges.
2. Navigate to the directory containing the `win-installation-pymor.bat` script.
3. Run the script:
   ```cmd
   install_pymor_dependencies.bat