@echo off
echo ==== INSTALLATION OF PYTHON PACKAGES FOR ODEs AND NGSOLVE ====
echo.

echo ==== Check / Install Python 3.12 and PIP ======
echo Note: Ensure you have admin privileges for installation.
echo.

REM Check if Python 3.12 is installed
for /f "tokens=2 delims==" %%a in ('wmic product where "name like 'Python%%'" get version /format:list') do (
    echo Found Python version: %%a
    if "%%a" GEQ "3.12" (
        echo Python 3.12 or newer is already installed.
        goto InstallPip
    )
)

echo Downloading and installing Python 3.12...
REM Change the URL to the official Python 3.12 installer if needed
set PYTHON_INSTALLER_URL=https://www.python.org/ftp/python/3.12.0/python-3.12.0-amd64.exe
set INSTALLER=python-3.12.0-amd64.exe

powershell -Command "(New-Object System.Net.WebClient).DownloadFile('%PYTHON_INSTALLER_URL%', '%INSTALLER%')"
%INSTALLER% /quiet InstallAllUsers=1 PrependPath=1
if %ERRORLEVEL% NEQ 0 (
    echo Failed to install Python 3.12. Exiting...
    exit /b 1
)

:InstallPip
echo Installing or updating pip...
python -m ensurepip
python -m pip install --upgrade pip

echo ==== Installing scientific computing packages ====
python -m pip install numpy
python -m pip install scipy
python -m pip install matplotlib

echo ===== Installing NGSolve =====
python -m pip install --upgrade ngsolve

echo INSTALLATION COMPLETE!
pause
