@echo off
echo ################################################
echo #   - Installation of the C++ and Fortran      #
echo #     compilers.                               #
echo #   - Installation of Conda Package Manager    #
echo #   - Installation of PyMOR and                #
echo #     dependencies.                            #
echo #                                              #
echo #                02.12.2024                    #
echo ################################################
echo.

:: ===== Installation of C++ and Fortran Compilers =====
echo ">> Installing C++ and Fortran compilers..."

REM Function to check if a command exists
REM Uses `where` command to check existence
set "command_exists=where %1 >nul 2>&1 && exit /b 0 || exit /b 1"

REM Check for g++ (C++ compiler)
%command_exists% g++
if %errorlevel%==0 (
    echo "C++ compiler (g++) is already installed."
) else (
    echo "C++ compiler not found. Installing g++..."
    REM Add your g++ installation method here, e.g., downloading MinGW or MSYS2
    echo "Please manually install a C++ compiler (MinGW or MSYS2)."
)

REM Check for gfortran (Fortran compiler)
%command_exists% gfortran
if %errorlevel%==0 (
    echo "Fortran compiler (gfortran) is already installed."
) else (
    echo "Fortran compiler not found. Installing gfortran..."
    REM Add your gfortran installation method here
    echo "Please manually install a Fortran compiler (MinGW or MSYS2)."
)

echo "Compiler check and installation complete."
echo.

:: ===== Installation of Conda Package Manager =====
echo ">> Installing the conda repository..."

REM Check if conda is already installed
%command_exists% conda
if %errorlevel%==0 (
    echo "Conda is already installed."
) else (
    echo "Downloading Miniconda installer..."
    set CONDA_INSTALLER_URL=https://repo.anaconda.com/miniconda/Miniconda3-latest-Windows-x86_64.exe
    set CONDA_INSTALLER=Miniconda3-latest-Windows-x86_64.exe

    powershell -Command "(New-Object System.Net.WebClient).DownloadFile('%CONDA_INSTALLER_URL%', '%CONDA_INSTALLER%')"
    echo "Running Miniconda installer..."
    %CONDA_INSTALLER% /InstallationType=JustMe /RegisterPython=0 /AddToPath=1 /S
    if %ERRORLEVEL% NEQ 0 (
        echo "Failed to install Conda. Exiting..."
        exit /b 1
    )
    echo "Conda installed successfully."
)

echo "Adding conda to the system PATH..."
call "%UserProfile%\Miniconda3\Scripts\activate.bat"
echo "Conda version:"
conda -V
echo.

REM Configure Conda Channels
conda config --remove channels defaults
conda config --add channels conda-forge

:: ===== PyMOR and Dependencies =====
echo ">> Install Numpy, Scipy, Matplotlib, PyMOR, and Slycot..."
conda install -c conda-forge numpy scipy matplotlib pymor slycot -y
conda update --all -y

echo.
echo "INSTALLATION COMPLETE!"
pause

